- x
An object of class("nma")
- bydose
A boolean object indicating whether to plot responses with dose
on the x-axis (TRUE) to be able to examine potential dose-response shapes, or
to plot a conventional forest plot with all treatments on the same plot (FALSE)
- scales
Should scales be fixed ("fixed", the default),
free ("free"), or free in one dimension ("free_x",
"free_y")?
- ...
Arguments to be sent to ggplot2::ggplot()
- network
An object of class mbnma.network.
- method
Indicates the type of split (treatment-level) NMA to perform when overlay.split=TRUE. Can
take either "common" or "random".
- likelihood
A string indicating the likelihood to use in the model. Can take either "binomial",
"normal" or "poisson". If left as NULL the likelihood will be inferred from the data.
- link
A string indicating the link function to use in the model. Can take any link function
defined within JAGS (e.g. "logit", "log", "probit", "cloglog"), be assigned the value "identity" for
an identity link function, or be assigned the value "smd" for modelling Standardised Mean Differences using an
identity link function. If left as NULL the link function will be automatically assigned based
on the likelihood.
- priors
A named list of parameter values (without indices) and
replacement prior distribution values given as strings
using distributions as specified in JAGS syntax (see jagsmanual;textualMBNMAdose).
- warn.rhat
A boolean object to indicate whether to return a warning if Rhat values
for any monitored parameter are >1.02 (suggestive of non-convergence).
- n.iter
number of total iterations per chain (including burn in; default: 20000)
- drop.discon
A boolean object that indicates whether or not to drop disconnected
studies from the network.
- UME
A boolean object to indicate whether to fit an Unrelated Mean Effects model
that does not assume consistency and so can be used to test if the consistency
assumption is valid.
- pd
Can take either:
pv only pV will be reported (as automatically outputted by R2jags).
plugin calculates pD by the plug-in
method spiegelhalter2002MBNMAdose. It is faster, but may output negative
non-sensical values, due to skewed deviances that can arise with non-linear models.
pd.kl calculates pD by the Kullback-Leibler divergence plummer2008MBNMAdose. This
will require running the model for additional iterations but is a more robust calculation for the effective
number of parameters in non-linear models.
popt calculates pD using an optimism adjustment which allows for calculation
of the penalized expected deviance plummer2008MBNMAdose.
- parameters.to.save
A character vector containing names of parameters
to monitor in JAGS