# 1st order fractional polynomial a value of 0.5 for the power
dfpoly(beta.1="rel", power.1=0.5)
# 2nd order fractional polynomial with relative effects for coefficients
# and a common and random pooling for the 1st and 2nd power respectively
dfpoly(degree=2, beta.1="rel", beta.2="rel",
power.1="common", power.2="random")
Run the code above in your browser using DataLab